(* ::Package:: *)

(* ::Subsubsection:: *)
(*(* eudiffgeo.m *)*)


(* ::Text:: *)
(*(* Created by Rolf Sulanke *)*)
(**)
(*(* Started April 21, 2009 *)*)
(*(* Revised October 20, 2014 *)*)
(**)
(*(* This package contains tools applied in notebooks about Euclidean and*)
(*M\[ODoubleDot]bius differential geometry, mainly in three or two dimensions. *)*)
(**)
(*(* Hint:s. *)
(**)
(*1. Be sure, that besides of this package also the packages  euvec.m and *)
(*tensalg.m are contained in the working directory.*)
(**)
(*2. After importing this package define the number dim (= dimension)  of the Euclidean vector space as a constant in the Global context of the notebook!*)
(*This number may be changed later in the notebook, if wanted. If it is defined before *)
(*importing the notebook it will be fixed for all the modules introduce in the packages! *)*)


(* ::Subsection:: *)
(*(* Copyright*)


(* ::Text:: *)
(*This notebook and the accompanying packages are  public. Authors who intend to publish a changed or completed version of them should do it under their own names with the condition that they cite the original notebook with the Internet address or other source where they got it. I am not responsible for errors or damages originated by the use of the procedures contained in my notebooks or packages; everybody who applies them should test carefully whether they are appropriate for his purposes. *)*)


BeginPackage["eudiffgeo`",{"tensalg`", "euvec`"}] 
   
(* The usages *)

circle2D::usage = "circle2D[t, r:1] is the parameter representation of the dircle in the plane with 
radius r and center at the origin.";

circ2D::usage = "circ2D[m, r:1][t] is the parameter representation of the 
dircle in the plane with radius r and center m."

spirgr::usage = "spirgr[t,a:1] is the parameter representation of the spiral 
tansformation group with parameter a in the Euclidean plane; a = 0 yields 
the group of rotattions around the origin.";

spiral::usage = "spiral[a:1,b:1][t] is a parameter representation of the logarithmic spiral 
in orthonormal coordinates of the Euclidean plane; a = 0 yields the circle of radius b with
center at the origin.";

tangent::usage= "tangent[curve][t] yields the tangent unit vector of the  curve[t].";

graph::usage ="graph[f][x,y,...] is the canonical parameter representation of the 
graph {x,y,...f[x,y,...]} of the function f, in arbitrary dimension."; 

arclength::usage="arclength[curve][ x] yields the arc length of the curve curve[x] as an indefinite
Integral; curve[x] must be given in orthonormal Cartesian coordinates.";

arc::usage = "arc[curve,x,y0,y] yields the length of the arc of the curve curve[x] for y0<x<y; 
curve[x] must be given in orthonormal Cartesian coordinates.";

curvature::usage = "curvature[curve][t] yields the absolute value of the curvature 
of the regular curve[t] in any dimension, as a function of an arbitrary parameter t.";

torsion::usage = "torsion[curve][t] yields the torsion of the curve[t] in 
the Euclidean 3-space; it is defined only at points with non vanishing curvature.";

frenet::usage = "frenet[curve][t] yields the Frenet frame for a generally curved 
curve[t] in the n-dimensional Euclidean space. Generally curved means that the 
rank of the first n-1 derivatives of curve[t] must be n-1 at each point t.";

curvatures::usage = "curvatures[curve][t] yields the n-1 curvatures of a generally curved 
curve[t] in the n-dimensional Euclidean space. Generally curved means that the 
rank of the first n-1 derivatives of curve[t] must be n-1 at each point t.";

assu::usage ="assu[c][s] is a set of assumptions in the first four derivatives of the 
parameter representation c[s] of a smooth curve in the n-dimensional Euclidean space 
giving True if s is the Euclidean arc length of the curve."


Begin["`Private`"] 

(* The spiral group in the plane *)

spirgr[t_,a_:1]:={{Cos[t],-Sin[t]},{Sin[t],Cos[t]}}*Exp[a*t];

spiral[a_:1, b_:1][t_] := spirgr[t,a].{b,0};

tangent[curve_][t_]:= Simplify[dotnorme[curve'[t]], t\[Element] Reals];

(* The graph of a function is formally very easy to define: *)

graph[f_][x___] := {x, f[x]};


arc[curve_,x_,y0_,y_]:= Simplify[Integrate[norm[curve'[x]],{x,y0,y}]];

arclength[curve_][x_]:= Simplify[Integrate[norm[curve'[x]],x]]; 

curvature[curve_][t_] := norm[ D[tangent[curve][t],t]]/norm[D[curve[t],t]];

torsion[curve_][t_] := Det[{D[curve[t],t], D[curve[t],{t,2}],D[curve[t],{t,3}]}]/norm[Cross[D[curve[t],t], D[curve[t],{t,2}]]]^2;

frenet[curve_][t_] := Module[{n = Length[curve[t]], v,i,w},
v = Table[D[curve[t],{t,i}],{i,1,n-1}];
w = Simplify[esorthonorm[v]];
If[Length[w]<n-1, Print[curve[t] , "is not generally curved!"]; Return[]];
v= Append[w, cross[w]]; v];

curvatures[curve_][t_]:= Module[{n = Length[curve[t]],cv, cc,i},
cv = frenet[curve][t];
If[cv == Null, Return[]];
For[i=1, i<n,i++,cc[i] = D[cv[[i]],t].cv[[i+1]]/norm[D[curve[t],t]]];
vec[cc,n-1]];

assu[c_][t_] :=(c'[t].c'[t]== 1&&c'[t].c''[t]==0&&-c'[t].c'''[t]==c''[t].c''[t]&&
-Derivative[1][c][t].Derivative[4][c][t]==3*c'''[t].c''[t]);

circ2D[m_List,r_:1][t_]:= m+r*{Cos[t],Sin[t]};

circle2D[t_, r_:1] := {Cos[t],Sin[t]}*r;
End[]
	
Protect[arc, arclength, assu, circ2D, circle2D, curvature, curvatures, frenet,  graph, spiral, 
spirgr, tangent, torsion];

EndPackage[]

